==> react-image-upload-grid-1.1.3.tgz: package/es/components/SortableItem.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

//NPM
import React from 'react';
import { SortableElement } from 'react-sortable-hoc';
import { StyleSheet, css } from 'aphrodite';

import { faFileAlt } from '@fortawesome/free-solid-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

var SortableItem = function (_React$Component) {
  _inherits(SortableElement, _React$Component);

  function SortableElement(props) {
    _classCallCheck(this, SortableElement);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _this.removeImage = function (e, index, id) {
      e.stopPropagation();
      _this.props.removeFile(index, id);
    };

    _this.handleMouseOver = function (e) {
      _this.setState({
        hover: true,
        showDiv: true
      });
    };

    _this.handleMouseLeave = function (e) {
      _this.setState({
        hover: false,
        showDiv: false
      });
    };

    _this.formatBytes = function (bytes) {
      var decimals = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;

      if (bytes === 0) return '0 Bytes';

      var k = 1024;
      var dm = decimals < 0 ? 0 : decimals;
      var sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];

      var i = Math.floor(Math.log(bytes) / Math.log(k));

      return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i];
    };

    _this.state = {
      hover: false, //saves id from events to specify changes
      showDiv: false //when true, shows button that allows user to remove image
    };
    return _this;
  }

  /**
   * Deletes image
   * @param { Event } e -- the onClick event
   * @param { Integer } index -- index of the item we clicked on to remove
   * @param { String } id -- the id of the item we want to delete
   */


  /**
   * Reveals button that allows user to delete image
   * @param { Event} e -- event triggered by MouseOver
   */


  /**
   * Hides button that allows user to delete image
   * @param { Event} e -- event triggerd by MouseLeave
   */


  SortableElement.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        src = _props.src,
        id = _props.id,
        index = _props.index,
        isPdf = _props.isPdf,
        image = _props.image;

    if (isPdf) {
      return React.createElement(
        'div',
        {
          className: 'DropZone ' + css(styles.DropZone) + ' ' + this.props.imageContainerClassName,
          id: 'dropzone' + id,
          onMouseEnter: this.handleMouseOver,
          onMouseLeave: this.handleMouseLeave
        },
        React.createElement(
          'div',
          { className: css(styles.inner, styles.pdfInner) },
          React.createElement(
            'span',
            { className: css(styles.file) },
            React.createElement(FontAwesomeIcon, { icon: faFileAlt })
          ),
          React.createElement(
            'div',
            { className: css(styles.metaContainer) },
            React.createElement(
              'div',
              { className: css(styles.pdfName) + ' meta' },
              image && image.name && image.name
            ),
            React.createElement(
              'div',
              { className: css(styles.pdfSize) },
              image && image.size && this.formatBytes(image.size)
            )
          ),
          this.state.hover ? React.createElement(
            'span',
            { className: css(styles.CloseButton), onClick: function onClick(e) {
                return _this2.removeImage(e, index, id);
              } },
            React.createElement(
              'p',
              { className: css(styles.ButtonText) },
              '-'
            )
          ) : null
        )
      );
    } else {
      return React.createElement(
        'div',
        {
          className: 'DropZone ' + css(styles.DropZone) + ' ' + this.props.imageContainerClassName,
          id: 'dropzone' + id,
          onMouseEnter: this.handleMouseOver,
          onMouseLeave: this.handleMouseLeave
        },
        React.createElement(
          'div',
          { className: css(styles.inner) },
          React.createElement('img', {
            draggable: 'false' //prevents user from dragging, else messes up 'react-sortable-hoc' 
            , className: css(styles.preview),
            id: id,
            src: src
          }),
          this.state.hover ? React.createElement(
            'span',
            { className: css(styles.CloseButton), onClick: function onClick(e) {
                return _this2.removeImage(e, index, id);
              } },
            React.createElement(
              'p',
              { className: css(styles.ButtonText) },
              '-'
            )
          ) : null
        )
      );
    }
  };

  return SortableElement;
}(React.Component);

var styles = StyleSheet.create({
  DropZone: {
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    width: 180,
    height: 180,
    margin: 10,
    boxSizing: 'border-box',
    lineHeight: 1.5,
    textAlign: "center",
    cursor: "pointer",
    borderRadius: 4,
    outline: 'none',
    zIndex: 3,
    backgroundColor: '#fff',
    border: '2px solid #ddd',
    ":hover": {
      boxShadow: 'rgba(129,148,167,0.39) 0px 3px 10px 0px'
    }
  },
  preview: {
    objectFit: "contain",
    width: "auto",
    height: "auto",
    minWidth: "100%",
    maxWidth: "100%",
    float: "left",
    overflow: "hidden"
  },
  inner: {
    position: 'relative',
    height: '100%',
    display: 'flex'
  },
  pdfInner: {
    display: 'flex',
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'center'
  },
  CloseButton: {
    position: "absolute",
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    alignItems: "center",
    zIndex: 100,
    top: 6,
    right: 6,
    height: 18,
    width: 18,
    borderRadius: "50%",
    color: "white",
    background: "rgba(255, 0, 0)",
    boxShadow: 'rgba(129,148,167,0.39) 0px 3px 20px 0px',
    transition: "all 0.2s ease-in-out",
    opacity: 0.8,
    ":hover": {
      opacity: 1
    }
  },
  ButtonText: {
    margin: 0,
    paddingBottom: 2
  },
  metaContainer: {
    display: 'flex',
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'center',
    width: '100%',
    padding: '0px 10px',
    boxSizing: 'border-box'
  },
  file: {
    fontSize: 40,
    color: '#C0C0C0'
  },
  pdfName: {
    fontSize: 15,
    fontWeight: 500
  },
  pdfSize: {
    fontSize: 13
  }
});

export default SortableElement(SortableItem);

==> react-image-upload-grid-1.1.4.tgz: package/es/components/SortableItem.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

//NPM
import React from 'react';
import { SortableElement } from 'react-sortable-hoc';
import { StyleSheet, css } from 'aphrodite';

import { faFileAlt } from '@fortawesome/free-solid-svg-icons/faFileAlt';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

var SortableItem = function (_React$Component) {
  _inherits(SortableElement, _React$Component);

  function SortableElement(props) {
    _classCallCheck(this, SortableElement);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _this.removeImage = function (e, index, id) {
      e.stopPropagation();
      _this.props.removeFile(index, id);
    };

    _this.handleMouseOver = function (e) {
      _this.setState({
        hover: true,
        showDiv: true
      });
    };

    _this.handleMouseLeave = function (e) {
      _this.setState({
        hover: false,
        showDiv: false
      });
    };

    _this.formatBytes = function (bytes) {
      var decimals = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;

      if (bytes === 0) return '0 Bytes';

      var k = 1024;
      var dm = decimals < 0 ? 0 : decimals;
      var sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];

      var i = Math.floor(Math.log(bytes) / Math.log(k));

      return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i];
    };

    _this.state = {
      hover: false, //saves id from events to specify changes
      showDiv: false //when true, shows button that allows user to remove image
    };
    return _this;
  }

  /**
   * Deletes image
   * @param { Event } e -- the onClick event
   * @param { Integer } index -- index of the item we clicked on to remove
   * @param { String } id -- the id of the item we want to delete
   */


  /**
   * Reveals button that allows user to delete image
   * @param { Event} e -- event triggered by MouseOver
   */


  /**
   * Hides button that allows user to delete image
   * @param { Event} e -- event triggerd by MouseLeave
   */


  SortableElement.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        src = _props.src,
        id = _props.id,
        index = _props.index,
        isPdf = _props.isPdf,
        image = _props.image;

    if (isPdf) {
      return React.createElement(
        'div',
        {
          className: 'DropZone ' + css(styles.DropZone) + ' ' + this.props.imageContainerClassName,
          id: 'dropzone' + id,
          onMouseEnter: this.handleMouseOver,
          onMouseLeave: this.handleMouseLeave
        },
        React.createElement(
          'div',
          { className: css(styles.inner, styles.pdfInner) },
          React.createElement(
            'span',
            { className: css(styles.file) },
            React.createElement(FontAwesomeIcon, { icon: faFileAlt })
          ),
          React.createElement(
            'div',
            { className: css(styles.metaContainer) },
            React.createElement(
              'div',
              { className: css(styles.pdfName) + ' meta' },
              image && image.name && image.name
            ),
            React.createElement(
              'div',
              { className: css(styles.pdfSize) },
              image && image.size && this.formatBytes(image.size)
            )
          ),
          this.state.hover ? React.createElement(
            'span',
            { className: css(styles.CloseButton), onClick: function onClick(e) {
                return _this2.removeImage(e, index, id);
              } },
            React.createElement(
              'p',
              { className: css(styles.ButtonText) },
              '-'
            )
          ) : null
        )
      );
    } else {
      return React.createElement(
        'div',
        {
          className: 'DropZone ' + css(styles.DropZone) + ' ' + this.props.imageContainerClassName,
          id: 'dropzone' + id,
          onMouseEnter: this.handleMouseOver,
          onMouseLeave: this.handleMouseLeave
        },
        React.createElement(
          'div',
          { className: css(styles.inner) },
          React.createElement('img', {
            draggable: 'false' //prevents user from dragging, else messes up 'react-sortable-hoc' 
            , className: css(styles.preview),
            id: id,
            src: src
          }),
          this.state.hover ? React.createElement(
            'span',
            { className: css(styles.CloseButton), onClick: function onClick(e) {
                return _this2.removeImage(e, index, id);
              } },
            React.createElement(
              'p',
              { className: css(styles.ButtonText) },
              '-'
            )
          ) : null
        )
      );
    }
  };

  return SortableElement;
}(React.Component);

var styles = StyleSheet.create({
  DropZone: {
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    width: 180,
    height: 180,
    margin: 10,
    boxSizing: 'border-box',
    lineHeight: 1.5,
    textAlign: "center",
    cursor: "pointer",
    borderRadius: 4,
    outline: 'none',
    zIndex: 3,
    backgroundColor: '#fff',
    border: '2px solid #ddd',
    ":hover": {
      boxShadow: 'rgba(129,148,167,0.39) 0px 3px 10px 0px'
    }
  },
  preview: {
    objectFit: "contain",
    width: "auto",
    height: "auto",
    minWidth: "100%",
    maxWidth: "100%",
    float: "left",
    overflow: "hidden"
  },
  inner: {
    position: 'relative',
    height: '100%',
    display: 'flex'
  },
  pdfInner: {
    display: 'flex',
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'center'
  },
  CloseButton: {
    position: "absolute",
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    alignItems: "center",
    zIndex: 100,
    top: 6,
    right: 6,
    height: 18,
    width: 18,
    borderRadius: "50%",
    color: "white",
    background: "rgba(255, 0, 0)",
    boxShadow: 'rgba(129,148,167,0.39) 0px 3px 20px 0px',
    transition: "all 0.2s ease-in-out",
    opacity: 0.8,
    ":hover": {
      opacity: 1
    }
  },
  ButtonText: {
    margin: 0,
    paddingBottom: 2
  },
  metaContainer: {
    display: 'flex',
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'center',
    width: '100%',
    padding: '0px 10px',
    boxSizing: 'border-box'
  },
  file: {
    fontSize: 40,
    color: '#C0C0C0'
  },
  pdfName: {
    fontSize: 15,
    fontWeight: 500
  },
  pdfSize: {
    fontSize: 13
  }
});

export default SortableElement(SortableItem);
